darkhistory.electrons.ics.ics_spectrum.thomson_spec_quad — DarkHistory documentation

# darkhistory.electrons.ics.ics_spectrum.thomson_spec_quad

`darkhistory.electrons.ics.ics_spectrum.` `thomson_spec_quad`(eleckineng_arr, photeng_arr, T)

  Thomson ICS spectrum of secondary photons using quadrature.

  Parameters: | eleckineng : ndarray Incoming electron kinetic energy. photeng : ndarray Outgoing photon energy. T : float CMB temperature.
  Returns: | ndarray dN/(dt dE) of the outgoing photons (dt = 1 s), with abscissa photeng.

  Notes

  Insert note on the suitability of the method.

#### Previous topic

darkhistory.electrons.ics.ics_spectrum.thomson_spec

#### Next topic

darkhistory.electrons.ics.ics_spectrum.rel_spec

### This Page

Show Source